#############################################################
#
# mtd provides us with mkfs.jffs2, to target JFFS2 filesystems
#
#############################################################

MTD_DIR:=$(BUILD_DIR)/mtd
MTD_SOURCE=mtd-snapshot-20050205.tar.bz2
MTD_SITE=http://files.gumstix.com
#MKFS_JFFS2=$(shell which mkfs.jffs2 || echo $(MTD_DIR)/util/mkfs.jffs2)
MKFS_JFFS2=mkfs.jffs2
JFFS2_DUMP=jffs2dump
FLASH_UTILS= \
	flash_erase \
	flash_info \
	flash_lock \
	flash_unlock \
	flashcp \
	ftl_format \
	ftl_check \
	mtd_debug

$(DL_DIR)/$(MTD_SOURCE):
	$(WGET) -P $(DL_DIR) $(MTD_SITE)/$(MTD_SOURCE)

$(MTD_DIR)/Makefile: $(DL_DIR)/$(MTD_SOURCE)
	bzcat $(DL_DIR)/$(MTD_SOURCE) | tar -C $(BUILD_DIR) -xf -
	$(SOURCE_DIR)/patch-kernel.sh $(MTD_DIR) $(SOURCE_DIR) mtd-*.patch
	touch $(MTD_DIR)/Makefile

$(MTD_DIR)/util/$(MKFS_JFFS2): $(MTD_DIR)/Makefile mtd-zlib-check
	CFLAGS=-I$(LINUX_DIR)/include $(MAKE) $(JLEVEL) LINUXDIR=$(LINUX_DIR) -C $(MTD_DIR)/util $(MKFS_JFFS2)

$(MTD_DIR)/util/$(JFFS2_DUMP): $(MTD_DIR)/Makefile mtd-zlib-check
	CFLAGS=-I$(LINUX_DIR)/include $(MAKE) $(JLEVEL) LINUXDIR=$(LINUX_DIR) -C $(MTD_DIR)/util $(JFFS2_DUMP)

$(addprefix $(MTD_DIR)/util/,$(FLASH_UTILS)): % : $(MTD_DIR)/Makefile %.c
	CFLAGS="$(TARGET_CFLAGS)" $(MAKE) $(JLEVEL) CROSS=$(KERNEL_CROSS) -C $(MTD_DIR)/util $(notdir $@)
	$(STRIP) $@


.PHONY: mtd-sources mtd-unpacked mtd-clean target-mtd-utils host-mkfs.jffs2

mtd-sources: $(DL_DIR)/$(MTD_SOURCE)

mtd-unpacked: $(MTD_DIR)/Makefile

mtd-clean:
	$(MAKE) -C $(MTD_DIR) clean

mtd-zlib-check:
	@if [ ! -e /usr/include/zlib.h ]; then echo /usr/include/zlib.h must be installed on the build system to build mtd utils; exit 1; fi

target-mtd-utils: $(addprefix $(TARGET_DIR)/sbin/,$(FLASH_UTILS))

$(addprefix $(TARGET_DIR)/sbin/,$(FLASH_UTILS)): $(TARGET_DIR)/sbin/% : $(MTD_DIR)/util/%
	install -m 0755 $< $(TARGET_DIR)/sbin

host-mtd-utils: $(STAGING_DIR)/sbin/$(MKFS_JFFS2) $(STAGING_DIR)/sbin/$(JFFS2_DUMP)

$(STAGING_DIR)/sbin/$(MKFS_JFFS2): $(MTD_DIR)/util/$(MKFS_JFFS2)
	install -m 0755 $< $(STAGING_DIR)/sbin

$(STAGING_DIR)/sbin/$(JFFS2_DUMP): $(MTD_DIR)/util/$(JFFS2_DUMP)
	install -m 0755 $< $(STAGING_DIR)/sbin
